types

package
v0.0.0-...-c26fdb2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2018 License: Apache-2.0 Imports: 0 Imported by: 8

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Action

type Action uint8

Action Has the set of actions possible

const (
	//CREATE create resource request
	CREATE Action = 0X01
	//BULKREAD get request on a resource
	//READ is by default bulk
	BULKREAD Action = 0X02
	//READ flag on action
	READ Action = 0x04
	//UPDATE update request on a resource
	UPDATE Action = 0X08
	//DELETE delete request on a resource
	DELETE Action = 0X10
)

func (Action) String

func (a Action) String() (action string)

String implements the fmt.Stringer interface

type ClientCredentials

type ClientCredentials struct {
	ClientID     string
	ClientSecret string
}

ClientCredentials The clients credetials the users credentials

type Credentials

type Credentials struct {
	UserCredentials
	ClientCredentials
}

Credentials user credentials and client credentials

type Error

type Error struct {
	Code     int    `json:"code"`
	HTTPCode int    `json:"status"`
	Message  string `json:"message"`
}

Error is a struct for platform error

type Mode

type Mode uint8

Mode The possible client running action

const (
	//PRODUCTION production mode says its not in debug mode
	PRODUCTION Mode = iota
	//DEBUG mode says that the client is in debug mode
	DEBUG
)

type UserCredentials

type UserCredentials struct {
	UserName    string
	AccessToken string
}

UserCredentials the users credentials

Jump to